@@ -129,9 +129,9 @@ def wait_for_jobs(backend: ShadeLocal, jobs: List[Jobs], paths: List[Path] = Non
 @pytest.mark.parametrize('demo_file_names', [
     ([
         'video/coverr-berlin-underground-train-7268-original.mp4',
-        # 'video/braw-r3d/A002_C305_0523UB_001.R3D',
+        'video/braw-r3d/A002_C305_0523UB_001.R3D',
         # TODO doesn't seem like braw is working
-        # 'video/In-The-Hand-Original.braw',
+        'video/Filmplusgear-skiers-Samnaun-2019-dci-Q5.braw',
 
         'image/exr-hdr-weird/bw_full.exr',
         'image/exr-hdr-weird/bw_half.exr',
@@ -143,6 +143,7 @@ def wait_for_jobs(backend: ShadeLocal, jobs: List[Jobs], paths: List[Path] = Non
         'image/DSC01974.ARW',
         'image/DSC04274.ARW',
         'image/FullSizeRender.heic',
+
         'image/android.demo-popover.gif',
         'image/photo-1.jpg',
         'image/photo-2.jpg',
